@@ -104,33 +104,22 @@ void a_Commands_viewsource_callback (GtkWidget *widget, gpointer client_data)
    a_Interface_text_window (&bw->viewsource_window,
                             "View Source", "view_source",
                             buf, buf_size,
-                            500, 500);
+                            530, 500);
 }
 
 /*
  * Show the detected HTML errors in current page.
  */
-gint a_Commands_view_page_bugs_callback (GtkWidget *button,
-                                           GdkEventButton *event,
-                                           gpointer client_data)
+void a_Commands_view_page_bugs_callback (GtkWidget *widget,
+                                         gpointer client_data)
 {
    DilloHtmlLB *html_lb = client_data;
 
-   if (event->button == 1) {
-      /* Show it */
-      a_Interface_text_window (&html_lb->bw->pagebugs_window,
-                               "Detected HTML errors", "page_bugs",
-                               html_lb->page_bugs->str,
-                               html_lb->page_bugs->len,
-                               500, 500);
-      return TRUE;
-   } else if (event->button == 3) {
-
-      gtk_menu_popup(GTK_MENU(html_lb->bw->menu_popup.over_bug), NULL, NULL,
-                     NULL, NULL, event->button, event->time);
-      return TRUE;
-   }
-   return FALSE;
+   a_Interface_text_window (&html_lb->bw->pagebugs_window,
+                            "Detected HTML errors", "page_bugs",
+                            html_lb->page_bugs->str,
+                            html_lb->page_bugs->len,
+                            530, 500);
 }
 
 /*
@@ -186,62 +175,55 @@ void a_Commands_back_callback(GtkWidget *widget, gpointer client_data)
 }
 
 /*
- * Second handler for button-press-event in the toolbar
+ * Creates the menu for the forward navigation button.
  */
-void a_Commands_navpress_callback(GtkWidget *widget,
-                                  GdkEventButton *event,
-                                  gpointer client_data)
+GtkMenu *a_Commands_forw_button_menu_creator_callback(GtkExtButton *button,
+                                                      gpointer client_data)
 {
    BrowserWindow *bw = client_data;
 
-   switch (event->button) {
-   case 1:
-      /* Handled by the default toolbar button handler */
-      break;
-   case 2:
-      /* Not used yet */
-      break;
-   case 3:
-      if (widget == bw->back_button) {
-         if (bw->menu_popup.over_back)
-            gtk_widget_destroy(bw->menu_popup.over_back);
-         bw->menu_popup.over_back = a_Menu_popup_history_new(bw, -1);
-         gtk_menu_popup(GTK_MENU (bw->menu_popup.over_back), NULL, NULL,
-                        NULL, NULL, event->button, event->time);
-
-      } else if (widget == bw->forw_button) {
-         if (bw->menu_popup.over_forw)
-            gtk_widget_destroy(bw->menu_popup.over_forw);
-         bw->menu_popup.over_forw = a_Menu_popup_history_new(bw, +1);
-         gtk_menu_popup(GTK_MENU (bw->menu_popup.over_forw), NULL, NULL,
-                        NULL, NULL, event->button, event->time);
-      }
-      break;
-   }
+   if (bw->menu_popup.over_forw)
+      gtk_widget_destroy(bw->menu_popup.over_forw);
+   bw->menu_popup.over_forw = a_Menu_popup_history_new(bw, +1);
+   return GTK_MENU(bw->menu_popup.over_forw);
 }
 
 /*
- * Second handler for button-press-event in history menus.
+ * Creates the menu for the backward navigation button.
  */
-void a_Commands_historypress_callback(GtkWidget *widget,
-                                      GdkEventButton *event,
-                                      gpointer client_data)
+GtkMenu *a_Commands_back_button_menu_creator_callback(GtkExtButton *button,
+                                                      gpointer client_data)
 {
    BrowserWindow *bw = client_data;
 
-   switch (event->button) {
-   case 1:
-      /* Open link in the same bw */
-      a_Nav_jump_callback(widget, bw, 0);
-      break;
-   case 2:
-      /* Open link in a new bw */
-      a_Nav_jump_callback(widget, bw, 1);
-      break;
-   case 3:
-      /* Not used */
-      break;
-   }
+   if (bw->menu_popup.over_back)
+      gtk_widget_destroy(bw->menu_popup.over_back);
+   bw->menu_popup.over_back = a_Menu_popup_history_new(bw, -1);
+   return GTK_MENU(bw->menu_popup.over_back);
+}
+
+/*
+ * Handler for menu entries in the history menus. This one is called, when
+ * the link should be opened in the same window.
+ */
+void a_Commands_history_callback_same_bw(GtkWidget *widget,
+                                         gpointer client_data)
+{
+   BrowserWindow *bw = client_data;
+
+   a_Nav_jump_callback(widget, bw, 0);
+}
+
+/*
+ * Handler for menu entries in the history menus. This one is called, when
+ * the link should be opened in a new window.
+ */
+void a_Commands_history_callback_new_bw(GtkWidget *widget,
+                                        gpointer client_data)
+{
+   BrowserWindow *bw = client_data;
+
+   a_Nav_jump_callback(widget, bw, 1);
 }
 
 /*
