@@ -147,13 +147,17 @@ typedef struct _DilloGif {
 /*
  * Forward declarations
  */
-static void Gif_write(DilloGif *gif, void *Buf, gint BufSize);
+static void Gif_write(DilloGif *gif, void *Buf, guint BufSize);
 static void Gif_close(DilloGif *gif, CacheClient_t *Client);
 static size_t Gif_process_bytes(DilloGif *gif, const guchar *buf,
-                                size_t bufsize, void *Buf);
+                                gint bufsize, void *Buf);
 static DilloGif *Gif_new(DilloImage *Image, DilloUrl *url, gint version);
 static void Gif_callback(int Op, CacheClient_t *Client);
 
+/* exported function */
+DwWidget *a_Gif_image(const char *Type, void *Ptr, CA_Callback_t *Call,
+                      void **Data);
+
 
 /*
  * MIME handler for "image/gif" type
@@ -166,7 +170,7 @@ DwWidget *a_Gif_image(const char *Type, void *Ptr, CA_Callback_t *Call,
    DICacheEntry *DicEntry;
 
    if ( !web->Image )
-      web->Image = a_Image_new(0, 0, NULL, NULL, prefs.bg_color);
+      web->Image = a_Image_new(0, 0, NULL, prefs.bg_color);
       /* todo: get the backgound color from the parent widget -- Livio. */
 
    /* Add an extra reference to the Image (for dicache usage) */
@@ -230,19 +234,19 @@ static void Gif_callback(int Op, CacheClient_t *Client)
 /*
  * Receive and process new chunks of GIF image data
  */
-static void Gif_write(DilloGif *gif, void *Buf, gint BufSize)
+static void Gif_write(DilloGif *gif, void *Buf, guint BufSize)
 {
    guchar *buf;
-   ssize_t bufsize, bytes_consumed;
+   gint bufsize, bytes_consumed;
 
    /* Sanity checks */
-   if (!Buf || !gif->Image || BufSize <= 0)
+   if (!Buf || !gif->Image || BufSize == 0)
       return;
 
    buf = ((guchar *) Buf) + gif->Start_Ofs;
    bufsize = BufSize - gif->Start_Ofs;
 
-   DEBUG_MSG(5, "Gif_write: %d bytes\n", BufSize);
+   DEBUG_MSG(5, "Gif_write: %u bytes\n", BufSize);
 
    /* Process the bytes in the input buffer. */
    bytes_consumed = Gif_process_bytes(gif, buf, bufsize, Buf);
@@ -251,7 +255,7 @@ static void Gif_write(DilloGif *gif, void *Buf, gint BufSize)
       return;
    gif->Start_Ofs += bytes_consumed;
 
-   DEBUG_MSG(5, "exit Gif_write, bufsize=%d\n", bufsize);
+   DEBUG_MSG(5, "exit Gif_write, bufsize=%ld\n", (glong)bufsize);
 }
 
 /*
@@ -265,8 +269,7 @@ static void Gif_close(DilloGif *gif, CacheClient_t *Client)
 
    a_Dicache_close(gif->url, gif->version, Client);
 
-   if (gif->linebuf != NULL)
-      g_free(gif->linebuf);
+   g_free(gif->linebuf);
 
    if (gif->spill_lines != NULL) {
       for (i = 0; i < gif->num_spill_lines_max; i++)
@@ -369,7 +372,7 @@ static inline size_t
  * Return value:
  *    TRUE when the extension is over
  */
-static size_t Gif_do_extension(DilloGif *gif, guchar Label,
+static size_t Gif_do_extension(DilloGif *gif, guint Label,
                                const guchar *buf,
                                size_t BSize)
 {
@@ -489,12 +492,11 @@ static void Gif_literal(DilloGif *gif, guint code)
 static void Gif_sequence(DilloGif *gif, guint code)
 {
    guint o_index, o_size, orig_code;
-   guchar *obuf = NULL;
    guint sequence_length = gif->length[code];
    guint line_index = gif->line_index;
    gint num_spill_lines;
    gint spill_line_index = gif->spill_line_index;
-   guchar *last_byte_ptr;
+   guchar *last_byte_ptr, *obuf;
 
    gif->length[gif->last_code + 1] = sequence_length + 1;
    gif->code_and_byte[gif->last_code + 1] = (code << 8);
@@ -576,7 +578,6 @@ static void Gif_sequence(DilloGif *gif, guint code)
    DEBUG_MSG(5, "\n");
 
    /* Output any full lines. */
-   o_index = gif->line_index;
    if (gif->line_index >= gif->Width) {
       Gif_emit_line(gif, gif->linebuf);
       gif->line_index = 0;
@@ -585,7 +586,7 @@ static void Gif_sequence(DilloGif *gif, guint code)
       if (gif->line_index)
          Gif_emit_line(gif, gif->linebuf);
       for (spill_line_index = 0;
-           spill_line_index < num_spill_lines - (o_index ? 1 : 0);
+           spill_line_index < num_spill_lines - (gif->line_index ? 1 : 0);
            spill_line_index++)
          Gif_emit_line(gif, gif->spill_lines[spill_line_index]);
    }
@@ -757,7 +758,7 @@ static gint Gif_decode(DilloGif *gif, const guchar *buf, size_t bsize)
 /*
  * ?
  */
-static gint Gif_check_sig(DilloGif *gif, const guchar *ibuf, size_t ibsize)
+static gint Gif_check_sig(DilloGif *gif, const guchar *ibuf, gint ibsize)
 {
    /* at beginning of file - read magic number */
    if (ibsize < 6)
@@ -800,7 +801,7 @@ static inline size_t
  * <Logical Screen> ::= Logical Screen Descriptor [Global Color Table]
  */
 static size_t Gif_get_descriptor(DilloGif *gif, void *Buf,
-                                 const guchar *buf, size_t bsize)
+                                 const guchar *buf, gint bsize)
 {
 
    /* screen descriptor */
@@ -813,7 +814,8 @@ static size_t Gif_get_descriptor(DilloGif *gif, void *Buf,
    Flags = buf[4];
 
    if (Flags & LOCALCOLORMAP) {
-      mysize = Gif_do_color_table(gif, Buf, buf + 7, bsize - 7, Flags & 0x7);
+      mysize = Gif_do_color_table(
+                  gif, Buf, buf + 7, (size_t)bsize - 7, Flags & (size_t)0x7);
       if (!mysize)
          return 0;
       Size += mysize;           /* Size of the color table that follows */
@@ -858,7 +860,8 @@ static size_t Gif_do_img_desc(DilloGif *gif, void *Buf,
    bsize -= 9;
    buf += 9;
    if (Flags & LOCALCOLORMAP) {
-      size_t LSize = Gif_do_color_table(gif, Buf, buf, bsize, Flags & 0x7);
+      size_t LSize = Gif_do_color_table(
+                        gif, Buf, buf, bsize, Flags & (size_t)0x7);
 
       if (!LSize)
          return 0;
@@ -992,7 +995,7 @@ static size_t GIF_Block(DilloGif * gif, void *Buf,
  * there has been gotten and set up.  So we stream it outside.
  */
 static size_t Gif_process_bytes(DilloGif *gif, const guchar *ibuf,
-                                size_t bufsize, void *Buf)
+                                gint bufsize, void *Buf)
 {
    gint tmp_bufsize = bufsize;
    size_t mysize;
@@ -1020,7 +1023,7 @@ static size_t Gif_process_bytes(DilloGif *gif, const guchar *ibuf,
        * the GIF grammar.  All sorts of stuff is allocated to set up for the
        * decode part (state ==2) and then there is the actual decode part (3)
        */
-      mysize = GIF_Block(gif, Buf, ibuf, tmp_bufsize);
+      mysize = GIF_Block(gif, Buf, ibuf, (size_t)tmp_bufsize);
       if (!mysize)
          break;
       tmp_bufsize -= mysize;
@@ -1031,7 +1034,7 @@ static size_t Gif_process_bytes(DilloGif *gif, const guchar *ibuf,
    case 3:
       /* get an image byte */
       /* The users sees all of this stuff */
-      mysize = Gif_decode(gif, ibuf, tmp_bufsize);
+      mysize = Gif_decode(gif, ibuf, (size_t)tmp_bufsize);
       if (mysize == 0)
          break;
       ibuf += mysize;
@@ -1043,8 +1046,8 @@ static size_t Gif_process_bytes(DilloGif *gif, const guchar *ibuf,
       break;
    }
 
-   DEBUG_MSG(5, "Gif_process_bytes: final state %d, %d bytes consumed\n",
-             gif->state, bufsize - tmp_bufsize);
+   DEBUG_MSG(5, "Gif_process_bytes: final state %d, %ld bytes consumed\n",
+             gif->state, (glong)(bufsize - tmp_bufsize));
 
    return bufsize - tmp_bufsize;
 }
