@@ -39,9 +39,10 @@ static GSList *ValidWebs = NULL;  /* Active web structures list; it holds
 /*
  * Given the MIME content type, and a fd to read it from,
  * this function connects the proper MIME viewer to it.
+ * Return value: 1 on success, -1 for unhandled MIME types
  */
-DwWidget* a_Web_dispatch_by_type (const char *Type, DilloWeb *Web,
-                                  CA_Callback_t *Call, void **Data)
+gint a_Web_dispatch_by_type (const char *Type, DilloWeb *Web,
+                             CA_Callback_t *Call, void **Data)
 {
    DwWidget *dw = NULL;
    DwStyle style_attrs, *style;
@@ -49,12 +50,13 @@ DwWidget* a_Web_dispatch_by_type (const char *Type, DilloWeb *Web,
 
    DEBUG_MSG(1, "a_Web_dispatch_by_type\n");
 
-   g_return_val_if_fail(Web->bw != NULL, NULL);
+   g_return_val_if_fail(Web->bw != NULL, -1);
 
    if (Web->flags & WEB_RootUrl) {
       /* We have RootUrl! */
       dw = a_Mime_set_viewer(Type, Web, Call, Data);
-      g_return_val_if_fail(dw != NULL, NULL);
+      if (dw == NULL)
+         return -1;
 
       /* Set a style for the widget */
       font.name = prefs.vw_fontname; /* must be defined */
@@ -76,13 +78,16 @@ DwWidget* a_Web_dispatch_by_type (const char *Type, DilloWeb *Web,
       a_Dw_gtk_scrolled_window_set_dw(
          GTK_DW_SCROLLED_WINDOW(Web->bw->docwin), dw);
 
-      if (URL_POSX(Web->url) || URL_POSY(Web->url))
+      if (URL_POSX(Web->url) || URL_POSY(Web->url)) {
         a_Dw_gtk_scrolled_window_set_scrolling_position(
            GTK_DW_SCROLLED_WINDOW(Web->bw->docwin),
            URL_POSX(Web->url), URL_POSY(Web->url));
-      else
+      } else {
+        gchar *pf = a_Url_decode_hex_str(URL_FRAGMENT_(Web->url));
         a_Dw_gtk_scrolled_window_set_anchor(
-           GTK_DW_SCROLLED_WINDOW(Web->bw->docwin), URL_FRAGMENT_(Web->url));
+           GTK_DW_SCROLLED_WINDOW(Web->bw->docwin), pf);
+        g_free(pf);
+      }
 
       /* Clear the title bar for pages without a <TITLE> tag */
       a_Interface_set_page_title(Web->bw, "");
@@ -96,18 +101,14 @@ DwWidget* a_Web_dispatch_by_type (const char *Type, DilloWeb *Web,
 
    } else {
       /* A non-RootUrl. At this moment we only handle image-children */
-      if (!g_strncasecmp(Type, "image/", 6)) {
+      if (!g_strncasecmp(Type, "image/", 6))
          dw = a_Mime_set_viewer(Type, Web, Call, Data);
-      } else {
-         *Call = a_Cache_null_client;
-         *Data = NULL;
-      }
    }
 
    if (!dw) {
       MSG_HTTP("unhandled MIME type: \"%s\"\n", Type);
    }
-   return dw;
+   return (dw ? 1 : -1);
 }
 
 
@@ -118,6 +119,7 @@ DilloWeb* a_Web_new(const DilloUrl *url)
 {
    DilloWeb *web= g_new(DilloWeb, 1);
 
+   _MSG(" a_Web_new: ValidWebs ==> %d\n", g_slist_length(ValidWebs));
    web->url = a_Url_dup(url);
    web->bw = NULL;
    web->flags = 0;
